### -*- coding: utf-8 -*- ####################################################
##############################################################################
#
# Copyright (c) 2008-2013 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

__docformat__ = "restructuredtext"

# import standard packages

# import Zope3 interfaces

# import local interfaces
from ztfy.blog.defaultskin.layer import IZBlogDefaultLayer, IZBlogDefaultSkin
from ztfy.bootstrap.layer import IBootstrapLayer

# import Zope3 packages
from zope.schema import TextLine

# import local packages

from ztfy.bootstrap import _


class IBootstrapBlogLayer(IBootstrapLayer, IZBlogDefaultLayer):
    """BootstrapBlog layer"""


class IBootstrapBlogSkin(IBootstrapBlogLayer, IZBlogDefaultSkin):
    """BootstrapBlog skin"""

    label = TextLine(title=_("Bootstrap blog skin"))
